<?php
/**
 * Plugin name: Debug EA/PUE Connectivity
 * Description: Temporary plugin to aid the debugging process surrounding connectivity issues with Event Aggregator and PUE.
 * Version:     1.0
 * Author:      Modern Tribe, Inc (Support Team)
 * Author URI:  https://theeventscalendar.com
 */

class Debug_EA_PUE_Connectivity {
	public function __construct() {
		add_action( 'tribe_help_pre_get_sections', array( $this, 'section' ) );
	}

	public function section( Tribe__Admin__Help_Page $help ) {
		$help->add_section( 'debug-ea-pue-connectivity', 'Debug EA|PUE Connectivity', 100 );
		$help->add_section_content( 'debug-ea-pue-connectivity', $this->report() );
	}

	public function report() {
		$output = '';
		$ea_response = wp_remote_get( 'https://ea.theeventscalendar.com' );
		$pue_response = wp_remote_get( 'https://pue.tri.be' );

		// Look at EA response
		$output .= '<p><strong>EA Server</strong></p>';

		if ( is_wp_error( $ea_response ) ) {
			$output .= '<p> Error: ' . esc_html( $ea_response->get_error_message() ) . '</p>';
		}
		else {
			$output .= '<p> Response: ' . esc_html( $ea_response['response']['code'] ) . '</p>';
		}

		// Look at PUE response
		$output .= '<p><strong>PUE Server</strong></p>';

		if ( is_wp_error( $pue_response ) ) {
			$output .= '<p> Error: ' . esc_html( $pue_response->get_error_message() ) . '</p>';
		}
		else {
			$output .= '<p> Response: ' . esc_html( $pue_response['response']['code'] ) . '</p>';
		}

		return $output;
	}
}

new Debug_EA_PUE_Connectivity;